@@ -199,3 +199,41 @@ class AlignmentAlgorithm:
             )
 
         return self._output_target_text_chunk_indices
+
+    def __str__(self):
+        query_to_target_alignment = {
+            x.query_idx: chr(self._target[x.target_idx])
+            for x in self._alignment.alignments
+        }
+        target_to_query_alignment = {
+            x.target_idx: chr(self._query[x.query_idx])
+            for x in self._alignment.alignments
+        }
+        return (
+            "Query <-> Target\n"
+            + "\n".join(
+                [
+                    chr(code)
+                    + "<->"
+                    + (
+                        query_to_target_alignment[idx]
+                        if idx in query_to_target_alignment
+                        else ""
+                    )
+                    for idx, code in enumerate(self._query)
+                ]
+            )
+            + "\nTarget <-> Query\n"
+            + "\n".join(
+                [
+                    chr(code)
+                    + "<->"
+                    + (
+                        target_to_query_alignment[idx]
+                        if idx in target_to_query_alignment
+                        else ""
+                    )
+                    for idx, code in enumerate(self._target)
+                ]
+            )
+        )
