@@ -2,10 +2,8 @@
 
 from text_alignment_tool.alignment_algorithms import AlignmentAlgorithm
 from text_alignment_tool.shared_classes import (
-    TextChunk,
     LetterList,
     TextAlignments,
-    AlignmentKey,
 )
 import swalign
 
