@@ -4,7 +4,7 @@ from text_alignment_tool.alignment_algorithms import (
     AlignmentException,
     AlignmentAlgorithm,
 )
-from typing import Sequence, Union
+from typing import Union
 from text_alignment_tool.alignment_tool.aligner import (
     AlignmentOperation,
     QueryTargetAlignment,
